---
title: "S3 Object Storage"
geekdocDescription: "S3 Object Service"
weight: 65
---
burble.dn42 provides an S3 compatible storage service based on [min.io](https://min.io/).

- [https://minio.burble.dn42](https://minio.burble.dn42) - Web interface
- s3.burble.dn42 - S3 compatible interface

{{<hint warning>}}
Remember that the storage service is provided for the dn42 community and 
the [burble.dn42 abuse policy](/network/abuse/) applies. 

Be considerate in your usage so that others will get the same benefits as
you are enjoying now. Clean up files that you no longer need, do not use the service for 
illegal or objectional content and don't be stupid.
{{</hint>}}

## Accessing the Service

The object storage service is available for all users who have set a burble.dn42
password via the [service portal](https://svc.burble.dn42).

### Web Interface

- [https://minio.burble.dn42](https://minio.burble.dn42)

The minio web console can be accessed by logging in using your burble.dn42
username (lowercase of your MNTNER without the -MNT suffix) and password. 

From the web interface users can create your own buckets, upload or download
files, and create access keys for the S3 service.

{{<hint info>}}
Any buckets you create must start with your lowercase MNTNER name followed by a dash.

For example, for FOOBAR-MNT buckets must start with 'foobar-'

Valid bucket names
```text
foobar-mybucket
foobar-bucket1
```

Invalid bucket names
```text
foobar
foobarmnt-bucket
notfoobar-bucket
```
{{</hint>}}

### S3 API

- s3.burble.dn42

An S3 compatible API is accessible via https://s3.burble.dn42. The S3 region is `uk-lon2`

{{<hint info>}}
Don't use your burble.dn42 username and password.  
Use the web interface on [https://minio.burble.dn42](https://minio.burble.dn42) to create a unique access and secret key when using the S3 API.
{{</hint>}}

## Example usage

### Using the minio client utility

1) Install the [minio client](https://min.io/docs/minio/linux/reference/minio-mc.html#quickstart)
2) Log in to the web console at https://minio.burble.dn42 using your burble.dn42 username and password
3) Create yourself a bucket, remember to start the bucket with your mntner e.g. 'foobar-'
4) Create an acccess and secret key pair
5) Log out the web interface and return back to the cli
6) [Create an alias](https://min.io/docs/minio/linux/reference/minio-mc.html#create-an-alias-for-the-s3-compatible-service) in the client using the access and secret key pair generated in step 4

```text
mc alias set burble https://s3.burble.dn42 ACCESS_KEY SECRET KEY
```

5) You can now use the client to access your bucket

```text
mc ls burble/foobar-mybucket
```

### Using the S3 API to mount buckets using rclone

The [burble.dn42 shell servers](/services/shell/) include rclone which you can use to mount 
buckets directly in your shell account.

1) Log in to the web console at https://minio.burble.dn42 using your burble.dn42 username and password
2) Create yourself a bucket, remember to start the bucket with your mntner e.g. 'foobar-'
3) Create an acccess and secret key pair
4) Log out the web interface and and log in to your shell account
5) Use [`rclone config`](https://rclone.org/s3/#minio) to configure rclone
 - Use https://s3.burble.dn42 as the endpoint and uk-lon2 as the region
 - Use the access and secret key pair created in step 3 for authentication

You can now use rclone to mount your buckets in the shell

```text
$ mkdir tmp
$ rclone mount burble: tmp
```

